package com.yd.dal.mapper.customer;

import com.yd.api.practitioner.vo.hiring.QueryMembershipRequestVO;
import com.yd.dal.entity.customer.AclPractitionerHiringMembership;
import java.util.List;
import org.apache.ibatis.annotations.Param;

public interface AclPractitionerHiringMembershipMapper {
    int deleteByPrimaryKey(Long id);

    int insert(AclPractitionerHiringMembership record);

    int insertSelective(AclPractitionerHiringMembership record);

    AclPractitionerHiringMembership selectByPrimaryKey(Long id);

    int updateByPrimaryKeySelective(AclPractitionerHiringMembership record);

    int updateByPrimaryKey(AclPractitionerHiringMembership record);

    int updateBatch(List<AclPractitionerHiringMembership> list);

    int updateBatchSelective(List<AclPractitionerHiringMembership> list);

    int batchInsert(@Param("list") List<AclPractitionerHiringMembership> list);

    AclPractitionerHiringMembership queryByhiringBasicInfoId(QueryMembershipRequestVO requestVO);
}